@@ -5,14 +5,18 @@ import click
 from kks.ejudge_submit import submit_solution
 from kks.util.common import prompt_choice, find_problem_rootdir
 from kks.util.ejudge import EjudgeSession
-from kks.errors import AuthError
+
+
+API_TESTING_TIMEOUT = 10
 
 
 @click.command(short_help='Submit a solutions')
 @click.argument('file', type=click.Path(exists=True), required=False)
 @click.option('-p', '--problem', type=str,
               help='manually specify the problem ID')
-def submit(file, problem):
+@click.option('-t', '--timeout', type=float, default=API_TESTING_TIMEOUT,
+              help=f'how long to wait for a testing report (default {API_TESTING_TIMEOUT}s)')
+def submit(file, problem, timeout):
     """
     Submit a solution
 
@@ -33,14 +37,10 @@ def submit(file, problem):
         if file is None:
             return
 
-    try:
-        session = EjudgeSession()
-    except AuthError:
-        return
+    session = EjudgeSession()
 
-    res, msg = submit_solution(session, file, problem)
-    color = 'green' if res else 'red'
-    click.secho(msg, fg=color)
+    result = submit_solution(session, file, problem, timeout)
+    click.secho(result.msg, fg=result.color())
 
 
 def get_problem_id(rootdir):
